@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-dialog.h,v 1.3 2003/11/19 19:19:55 chpe Exp $
+ *  $Id: ephy-embed-dialog.h,v 1.5 2005/01/08 19:41:46 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_DIALOG_H
@@ -37,11 +37,11 @@ G_BEGIN_DECLS
 #define EPHY_IS_EMBED_DIALOG_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_EMBED_DIALOG))
 #define EPHY_EMBED_DIALOG_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_EMBED_DIALOG, EphyEmbedDialogClass))
 
-typedef struct EphyEmbedDialogClass EphyEmbedDialogClass;
-typedef struct EphyEmbedDialog EphyEmbedDialog;
-typedef struct EphyEmbedDialogPrivate EphyEmbedDialogPrivate;
+typedef struct _EphyEmbedDialogClass	EphyEmbedDialogClass;
+typedef struct _EphyEmbedDialog		EphyEmbedDialog;
+typedef struct _EphyEmbedDialogPrivate	EphyEmbedDialogPrivate;
 
-struct EphyEmbedDialog
+struct _EphyEmbedDialog
 {
         EphyDialog parent;
 
@@ -49,7 +49,7 @@ struct EphyEmbedDialog
         EphyEmbedDialogPrivate *priv;
 };
 
-struct EphyEmbedDialogClass
+struct _EphyEmbedDialogClass
 {
         EphyDialogClass parent_class;
 };
@@ -69,4 +69,3 @@ EphyEmbed *		ephy_embed_dialog_get_embed		(EphyEmbedDialog *dialog);
 G_END_DECLS
 
 #endif
-
