@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-event.h,v 1.11 2004/02/20 11:49:42 chpe Exp $
+ *  $Id: ephy-embed-event.h,v 1.17 2005/02/27 14:13:45 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_EVENT_H
@@ -34,36 +34,29 @@ G_BEGIN_DECLS
 #define EPHY_IS_EMBED_EVENT_IFACE(k)		(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_EMBED_EVENT))
 #define EPHY_EMBED_EVENT_GET_IFACE(inst)	(G_TYPE_INSTANCE_GET_INTERFACE ((inst), EPHY_TYPE_EMBED_EVENT, EphyEmbedEventIface))
 
-typedef struct EphyEmbedEventIface	EphyEmbedEventIface;
-typedef struct EphyEmbedEvent		EphyEmbedEvent;
+typedef struct _EphyEmbedEventIface	EphyEmbedEventIface;
+typedef struct _EphyEmbedEvent		EphyEmbedEvent;
 
 typedef enum
 {
-	EMBED_CONTEXT_NONE     = 0,
-        EMBED_CONTEXT_DEFAULT  = 1 << 1,
-        EMBED_CONTEXT_LINK     = 1 << 2,
-        EMBED_CONTEXT_IMAGE    = 1 << 3,
-        EMBED_CONTEXT_DOCUMENT = 1 << 4,
-        EMBED_CONTEXT_INPUT    = 1 << 5,
-        EMBED_CONTEXT_XUL      = 1 << 7,
-	EMBED_CONTEXT_EMAIL_LINK = 1 << 8
-} EmbedEventContext;
+	EPHY_EMBED_CONTEXT_NONE			= 0,
+        EPHY_EMBED_CONTEXT_DEFAULT		= 1 << 1,
+        EPHY_EMBED_CONTEXT_LINK			= 1 << 2,
+        EPHY_EMBED_CONTEXT_IMAGE		= 1 << 3,
+        EPHY_EMBED_CONTEXT_DOCUMENT		= 1 << 4,
+        EPHY_EMBED_CONTEXT_INPUT		= 1 << 5,
+	EPHY_EMBED_CONTEXT_INPUT_PASSWORD	= 1 << 6,
+        EPHY_EMBED_CONTEXT_XUL			= 1 << 7,
+	EPHY_EMBED_CONTEXT_EMAIL_LINK		= 1 << 8
+} EphyEmbedEventContext;
 
-typedef enum
-{
-	EPHY_EMBED_EVENT_MOUSE_BUTTON1,
-	EPHY_EMBED_EVENT_MOUSE_BUTTON2,
-	EPHY_EMBED_EVENT_MOUSE_BUTTON3,
-	EPHY_EMBED_EVENT_KEY
-} EphyEmbedEventType;
-
-struct EphyEmbedEventIface
+struct _EphyEmbedEventIface
 {
 	GTypeInterface parent_iface;
 
 	/* Methods */
-	EphyEmbedEventType	(* get_type)		(EphyEmbedEvent *event);
-	EmbedEventContext	(* get_context)		(EphyEmbedEvent *event);
+	EphyEmbedEventContext	(* get_context)		(EphyEmbedEvent *event);
+	guint			(* get_button)		(EphyEmbedEvent *event);
 	guint			(* get_modifier)	(EphyEmbedEvent *event);
 	void			(* get_coordinates)	(EphyEmbedEvent *event,
 							 guint *x,
@@ -76,11 +69,15 @@ struct EphyEmbedEventIface
 	gpointer		(* get_dom_event)	(EphyEmbedEvent *event);
 };
 
-GType			ephy_embed_event_get_type	(void);
+GType			ephy_embed_event_get_type		(void);
 
-EphyEmbedEventType	ephy_embed_event_get_event_type	(EphyEmbedEvent *event);
+GType			ephy_embed_event_context_get_type	(void);
 
-EmbedEventContext	ephy_embed_event_get_context	(EphyEmbedEvent *event);
+GType			ephy_embed_event_type_get_type 		(void);
+
+EphyEmbedEventContext	ephy_embed_event_get_context	(EphyEmbedEvent *event);
+
+guint			ephy_embed_event_get_button	(EphyEmbedEvent *event);
 
 guint			ephy_embed_event_get_modifier	(EphyEmbedEvent *event);
 
