@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-shell.c,v 1.29 2005/01/28 22:23:20 chpe Exp $
+ *  $Id: ephy-embed-shell.c,v 1.31 2005/07/10 19:15:41 chpe Exp $
  */
 
 #include "config.h"
@@ -43,6 +43,14 @@ struct _EphyEmbedShellPrivate
 	EphyEncodings *encodings;
 };
 
+enum
+{
+	PREPARE_CLOSE,
+	LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL] = { 0 };
+
 static void ephy_embed_shell_class_init	(EphyEmbedShellClass *klass);
 static void ephy_embed_shell_init	(EphyEmbedShell *shell);
 
@@ -204,6 +212,12 @@ ephy_embed_shell_get_encodings (EphyEmbedShell *shell)
 	return G_OBJECT (shell->priv->encodings);
 }
 
+void
+ephy_embed_shell_prepare_close (EphyEmbedShell *shell)
+{
+	g_signal_emit (shell, signals[PREPARE_CLOSE], 0);
+}
+
 static void
 ephy_embed_shell_init (EphyEmbedShell *shell)
 {
@@ -225,5 +239,22 @@ ephy_embed_shell_class_init (EphyEmbedShellClass *klass)
 
 	klass->get_embed_single = impl_get_embed_single;
 
+/**
+ * EphyEmbed::prepare-close:
+ * @shell:
+ * 
+ * The ::prepare-close signal is emitted when epiphany is preparing to
+ * quit on command from the session manager. You can use it when you need
+ * to do something special (shut down a service, for example).
+ **/
+	signals[PREPARE_CLOSE] =
+		g_signal_new ("prepare-close",
+			      EPHY_TYPE_EMBED_SHELL,
+			      G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EphyEmbedShellClass, prepare_close),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
+	
 	g_type_class_add_private (object_class, sizeof (EphyEmbedShellPrivate));
 }
