@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.h,v 1.29 2005/01/30 15:20:35 chpe Exp $
+ *  $Id: ephy-embed-single.h,v 1.31 2005/07/24 21:37:01 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_SINGLE_H
@@ -66,8 +66,13 @@ struct _EphyEmbedSingleIface
 
 
         gboolean (* add_sidebar)    (EphyEmbedSingle *single,
-				     const char * url,
-				     const char * title);
+				     const char *url,
+				     const char *title);
+
+        gboolean (* add_search_engine) (EphyEmbedSingle *single,
+					const char *url,
+					const char *icon_url,
+					const char *title);
 
 	gboolean (* check_content)  (EphyEmbedSingle *single,
 				     EphyContentCheckType type,
@@ -88,7 +93,6 @@ struct _EphyEmbedSingleIface
 	gboolean	  (* get_offline_mode)	(EphyEmbedSingle *single);
 	GList *		  (* get_font_list)	(EphyEmbedSingle *shell,
 						 const char *langGroup);
-	GList *		  (* get_printer_list)	(EphyEmbedSingle *shell);
 };
 
 GType		ephy_embed_single_get_type		(void);
