@@ -36,7 +36,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.h,v 1.22 2005/04/26 12:01:39 chpe Exp $
+ * $Id: MozDownload.h,v 1.23 2005/07/07 13:10:25 chpe Exp $
  */
 
 #ifndef MozDownload_h__
@@ -135,8 +135,9 @@ public:
 #ifdef HAVE_GECKO_1_8
 	nsresult InitForEmbed       (nsIURI *aSource, nsIURI *aTarget,
 				     const nsAString &aDisplayName, nsIMIMEInfo *aMIMEInfo,
-				     PRTime aStartTime, nsICancelable *aCancelable,
-				     MozillaEmbedPersist *aEmbedPersist, PRInt64 aMaxSize);
+				     PRTime aStartTime, nsILocalFile *aTempFile,
+				     nsICancelable *aCancelable, MozillaEmbedPersist *aEmbedPersist,
+				     PRInt64 aMaxSize);
 #else
 	nsresult InitForEmbed       (nsIURI *aSource, nsIURI *aTarget,
 				     const PRUnichar *aDisplayName, nsIMIMEInfo *aMIMEInfo,
