@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed.cpp,v 1.106 2005/06/03 13:42:34 chpe Exp $
+ *  $Id: mozilla-embed.cpp,v 1.110 2005/07/12 20:47:21 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -201,6 +201,8 @@ static GObject *
 mozilla_embed_constructor (GType type, guint n_construct_properties,
 			   GObjectConstructParam *construct_params)
 {
+	g_object_ref (embed_shell);
+
 	/* we depend on single because of mozilla initialization */
 	ephy_embed_shell_get_embed_single (embed_shell);
 
@@ -289,6 +291,8 @@ mozilla_embed_finalize (GObject *object)
 	}
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
+
+	g_object_unref (embed_shell);
 }
 
 static void
@@ -486,10 +490,7 @@ static void
 impl_reload (EphyEmbed *embed, 
              gboolean force)
 {
-#ifdef HAVE_GECKO_1_8
-	guint32 mflags;
-
-	mflags = GTK_MOZ_EMBED_FLAG_RELOADNORMAL;
+	guint32 mflags = GTK_MOZ_EMBED_FLAG_RELOADNORMAL;
 
 	if (force)
 	{
@@ -497,15 +498,6 @@ impl_reload (EphyEmbed *embed,
 	}
 
 	gtk_moz_embed_reload (GTK_MOZ_EMBED(embed), mflags);
-#else
-	/* Workaround for broken reload with frames, see mozilla bug
-	 * http://bugzilla.mozilla.org/show_bug.cgi?id=246392
-	 */
-	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED (embed)->priv;
-
-	mpriv->browser->Reload (force ? EphyBrowser::RELOAD_FORCE :
-					EphyBrowser::RELOAD_NORMAL);
-#endif
 }
 
 static void
@@ -701,15 +693,8 @@ impl_set_encoding (EphyEmbed *embed,
 		if (NS_FAILED (rv)) return;
 	}
 
-#ifdef HAVE_GECKO_1_8
 	gtk_moz_embed_reload (GTK_MOZ_EMBED (embed),
 			      GTK_MOZ_EMBED_FLAG_RELOADCHARSETCHANGE);
-#else
-	/* Workaround for broken reload with frames, see mozilla bug
-	 * http://bugzilla.mozilla.org/show_bug.cgi?id=246392
-	 */
-	mpriv->browser->Reload (EphyBrowser::RELOAD_ENCODING_CHANGE);
-#endif
 }
 
 static char *
@@ -921,7 +906,6 @@ mozilla_embed_dom_key_press_cb (GtkMozEmbed *embed,
 				gpointer dom_event, 
 				MozillaEmbed *membed)
 {
-	MozillaEmbedPrivate *mpriv = membed->priv;
 	gint retval = FALSE;
 
 	if (dom_event == NULL) return FALSE;
@@ -1128,7 +1112,16 @@ _mozilla_embed_new_xul_dialog (void)
 {
 	GtkWidget *window, *embed;
 
+	g_object_ref (embed_shell);
+
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	g_object_set_data_full (G_OBJECT (window), "EmbedShellRef",
+			        embed_shell,
+				(GDestroyNotify) g_object_unref);
+	g_signal_connect_object (embed_shell, "prepare_close",
+				 G_CALLBACK (gtk_widget_destroy), window,
+				 (GConnectFlags) G_CONNECT_SWAPPED);
+
 	embed = gtk_moz_embed_new ();
 	gtk_widget_show (embed);
 	gtk_container_add (GTK_CONTAINER (window), embed);
