@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.c,v 1.26.2.2 2005/07/25 12:51:11 chpe Exp $
+ *  $Id: ephy-file-helpers.c,v 1.31 2005/07/25 12:56:20 chpe Exp $
  */
 
 #include "config.h"
@@ -165,9 +165,9 @@ const char *
 ephy_file (const char *filename)
 {
 	char *ret;
-	int i;
+	guint i;
 
-	static char *paths[] =
+	static const char * const paths[] =
 	{
 		SHARE_DIR "/",
 		SHARE_DIR "/glade/",
@@ -183,7 +183,7 @@ ephy_file (const char *filename)
 	if (ret != NULL)
 		return ret;
 
-	for (i = 0; i < (int) G_N_ELEMENTS (paths); i++)
+	for (i = 0; i < G_N_ELEMENTS (paths); i++)
 	{
 		ret = g_strconcat (paths[i], filename, NULL);
 		if (g_file_test (ret, G_FILE_TEST_EXISTS) == TRUE)
@@ -194,7 +194,7 @@ ephy_file (const char *filename)
 		g_free (ret);
 	}
 
-	g_warning (_("Failed to find %s"), filename);
+	g_warning ("Failed to find %s\n", filename);
 
 	return NULL;
 }
@@ -416,19 +416,19 @@ load_mime_from_xml (void)
 		tag = xmlTextReaderConstName (reader);
 		type = xmlTextReaderNodeType (reader);
 
-		if (xmlStrEqual (tag, "safe") && type == XML_READER_TYPE_ELEMENT)
+		if (xmlStrEqual (tag, (const xmlChar *)"safe") && type == XML_READER_TYPE_ELEMENT)
 		{
 			permission = EPHY_MIME_PERMISSION_SAFE;
 		}
-		else if (xmlStrEqual (tag, "unsafe") && type == XML_READER_TYPE_ELEMENT)
+		else if (xmlStrEqual (tag, (const xmlChar *)"unsafe") && type == XML_READER_TYPE_ELEMENT)
 		{
 			permission = EPHY_MIME_PERMISSION_UNSAFE;
 		}
-		else if (xmlStrEqual (tag, "mime-type"))
+		else if (xmlStrEqual (tag, (const xmlChar *)"mime-type"))
 		{
 			xmlChar *type;
 
-			type = xmlTextReaderGetAttribute (reader, "type");
+			type = xmlTextReaderGetAttribute (reader, (const xmlChar *)"type");
 			g_hash_table_insert (mime_table, type,
 					     GINT_TO_POINTER (permission));
 		}
@@ -834,8 +834,6 @@ ephy_file_launch_desktop_file (const char *filename,
 
 	for (i = 0; dirs[i] != NULL; i++)
 	{
-		g_print ("Looking in path: %s\n", dirs[i]);
-
 		path = g_build_filename (dirs[i], "applications", filename, NULL);
 
 		if (g_file_test (path, G_FILE_TEST_IS_REGULAR)) break;
