@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-state.c,v 1.35 2005/04/08 13:26:24 chpe Exp $
+ *  $Id: ephy-state.c,v 1.36 2005/07/03 21:38:54 jframeau Exp $
  */
 
 #include "config.h"
@@ -34,8 +34,8 @@
 #include <gtk/gtkexpander.h>
 
 #define EPHY_STATES_XML_FILE	"states.xml"
-#define EPHY_STATES_XML_ROOT    "ephy_states"
-#define EPHY_STATES_XML_VERSION "1.0"
+#define EPHY_STATES_XML_ROOT    (const xmlChar *)"ephy_states"
+#define EPHY_STATES_XML_VERSION (const xmlChar *)"1.0"
 
 enum
 {
@@ -63,7 +63,8 @@ ephy_states_save (void)
                                      NULL);
 
 	ephy_node_db_write_to_xml_safe
-		(states_db, xml_file,
+		(states_db, 
+		 (const xmlChar *)xml_file,
 		 EPHY_STATES_XML_ROOT,
 		 EPHY_STATES_XML_VERSION,
 		 NULL, /* comment */
