@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.171 2005/04/19 10:17:31 chpe Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.173 2005/07/11 19:47:25 chpe Exp $
  */
 
 #include "config.h"
@@ -1157,6 +1157,7 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 	gboolean key_normal = FALSE;
 	gboolean cut, copy, paste, select_all;
 	gboolean can_show_in_bookmarks_bar, show_in_bookmarks_bar = FALSE;
+	gboolean mutable = TRUE;
 	GtkActionGroup *action_group;
 	GtkAction *action;
 	GList *selected;
@@ -1229,6 +1230,7 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 		id = ephy_node_get_id (node);
 		show_in_bookmarks_bar = ephy_bookmarksbar_model_has_bookmark
 			(editor->priv->tb_model, id);
+		mutable = !ephy_node_get_property_boolean (node, EPHY_NODE_BMK_PROP_IMMUTABLE);
 
 		g_list_free (selected);
 	}
@@ -1251,12 +1253,12 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 
 	open_in_window = (bmk_focus && bmk_selection);
 	open_in_tab = (bmk_focus && bmk_selection);
-	rename = (bmk_focus && single_bmk_selected) ||
+	rename = (bmk_focus && single_bmk_selected && mutable) ||
 		 (key_selection && key_focus && key_normal);
-	delete = (bmk_focus && bmk_selection) ||
+	delete = (bmk_focus && bmk_selection && mutable) ||
 		 (key_selection && key_focus && key_normal);
-	properties = (bmk_focus && single_bmk_selected);
-	can_show_in_bookmarks_bar = (bmk_focus && single_bmk_selected) ||
+	properties = bmk_focus && single_bmk_selected && mutable;
+	can_show_in_bookmarks_bar = (bmk_focus && single_bmk_selected && mutable) ||
 		 (key_selection && key_focus);
 
 	action_group = editor->priv->action_group;
@@ -1389,10 +1391,17 @@ key_pressed_cb (EphyNodeView *view,
 		GdkEventKey *event,
 		EphyBookmarksEditor *editor)
 {
+	EphyBookmarksEditorPrivate *priv = editor->priv;
+	GtkAction *action;
+
 	if (event->keyval == GDK_Delete || event->keyval == GDK_KP_Delete)
 	{
-		cmd_delete (NULL, editor);
-		return TRUE;
+		action = gtk_action_group_get_action (priv->action_group, "Delete");
+		if (gtk_action_get_sensitive (action))
+		{
+			cmd_delete (NULL, editor);
+			return TRUE;
+		}
 	} 
 
 	return FALSE;
