@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topics-selector.c,v 1.24.4.2 2004/12/31 21:51:51 chpe Exp $
+ *  $Id: ephy-topics-selector.c,v 1.32 2005/01/28 22:25:02 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-topics-selector.h"
 #include "ephy-debug.h"
@@ -34,7 +32,7 @@ static void ephy_topics_selector_init (EphyTopicsSelector *editor);
 
 #define EPHY_TOPICS_SELECTOR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOPICS_SELECTOR, EphyTopicsSelectorPrivate))
 
-struct EphyTopicsSelectorPrivate
+struct _EphyTopicsSelectorPrivate
 {
 	EphyBookmarks *bookmarks;
 	EphyNode *bookmark;
@@ -56,7 +54,7 @@ ephy_topics_selector_get_type (void)
 {
 	static GType type = 0;
 
-	if (type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -83,7 +81,7 @@ static void
 ephy_topics_selector_set_bookmark (EphyTopicsSelector *selector,
 				   EphyNode *bookmark)
 {
-	LOG ("Set bookmark")
+	LOG ("Set bookmark");
 
 	selector->priv->bookmark = bookmark;
 
@@ -202,7 +200,7 @@ ephy_topics_selector_constructor (GType type,
 				   EPHY_NODE_KEYWORD_PROP_NAME,
 				   EPHY_NODE_VIEW_SHOW_PRIORITY |
 				   EPHY_NODE_VIEW_EDITABLE |
-				   EPHY_NODE_VIEW_SEARCHABLE, NULL);
+				   EPHY_NODE_VIEW_SEARCHABLE, NULL, NULL);
 	ephy_node_view_set_sort (EPHY_NODE_VIEW (selector), G_TYPE_STRING,
 				 EPHY_NODE_KEYWORD_PROP_NAME, GTK_SORT_ASCENDING);
 
@@ -267,8 +265,6 @@ static void
 ephy_topics_selector_init (EphyTopicsSelector *selector)
 {
 	selector->priv = EPHY_TOPICS_SELECTOR_GET_PRIVATE (selector);
-	selector->priv->bookmark = NULL;
-	selector->priv->topics = NULL;
 
 	selector->priv->filter = ephy_node_filter_new ();
 	ephy_node_filter_add_expression (selector->priv->filter,
