@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.74 2005/05/30 22:39:33 chpe Exp $
+ *  $Id: ephy-notebook.c,v 1.76 2005/07/16 15:01:32 chpe Exp $
  */
 
 #include "config.h"
@@ -725,7 +725,7 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 		char **split;
 
 		/* URL_TYPE has format: url \n title */
-		split = g_strsplit (selection_data->data, "\n", 2);
+		split = g_strsplit ((const gchar *)selection_data->data, "\n", 2);
 		if (split != NULL && split[0] != NULL && split[0][0] != '\0')
 		{
 			ephy_link_open (EPHY_LINK (notebook), split[0], tab,
