@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbar.c,v 1.12 2005/04/19 10:17:31 chpe Exp $
+ *  $Id: ephy-toolbar.c,v 1.14 2005/07/26 14:41:39 chpe Exp $
  */
 
 #include "config.h"
@@ -224,7 +224,7 @@ sync_user_input_cb (EphyLocationAction *action,
 	address = ephy_location_action_get_address (action);
 
 	priv->updating_address = TRUE;
-	ephy_tab_set_location (tab, address, EPHY_TAB_ADDRESS_EXPIRE_CURRENT);
+	ephy_tab_set_typed_address (tab, address);
 	priv->updating_address = FALSE;
 }
 
@@ -442,15 +442,16 @@ ephy_toolbar_get_location (EphyToolbar *toolbar)
 
 void
 ephy_toolbar_set_location (EphyToolbar *toolbar,
-			   const char *address)
+			   const char *address,
+			   const char *typed_address)
 {
 	EphyToolbarPrivate *priv = toolbar->priv;
 	EphyLocationAction *action = EPHY_LOCATION_ACTION (priv->actions[LOCATION_ACTION]);
-	
+
 	if (priv->updating_address) return;
 
 	priv->updating_address = TRUE;
-	ephy_location_action_set_address (action, address);
+	ephy_location_action_set_address (action, address, typed_address);
 	priv->updating_address = FALSE;
 }
 
