@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.288 2005/05/30 22:39:33 chpe Exp $
+ *  $Id: ephy-window.c,v 1.295 2005/07/26 14:41:39 chpe Exp $
  */
 
 #include "config.h"
@@ -200,9 +200,14 @@ static const GtkActionEntry ephy_menu_entries [] = {
 	{ "ViewStop", GTK_STOCK_STOP, N_("_Stop"), "Escape",
 	  N_("Stop current data transfer"),
 	  G_CALLBACK (window_cmd_view_stop) },
+	{ "ViewAlwaysStop", GTK_STOCK_STOP, N_("_Stop"), "Escape",
+	  NULL, G_CALLBACK (window_cmd_view_stop) },
 	{ "ViewReload", GTK_STOCK_REFRESH, N_("_Reload"), "<control>R",
 	  N_("Display the latest content of the current page"),
 	  G_CALLBACK (window_cmd_view_reload) },
+	{ "ForceReload", NULL, "", "<shift><control>R",
+	  NULL,
+	  G_CALLBACK (window_cmd_view_reload) },
 	{ "ViewZoomIn", GTK_STOCK_ZOOM_IN, N_("Zoom _In"), "<control>plus",
 	  N_("Increase the text size"),
 	  G_CALLBACK (window_cmd_view_zoom_in) },
@@ -702,6 +707,35 @@ ephy_window_key_press_event (GtkWidget *widget,
 	guint mask = gtk_accelerator_get_default_mod_mask ();
 	char *accel = NULL;
 
+	/* Handle ESC here instead of an action callback, so we can
+	 * handle it differently in the location entry, and we can
+	 * stop even when the page is not loading (to stop animations).
+	 */
+	if (event->keyval == GDK_Escape && (event->state & mask) == 0)
+	{
+		GtkWidget *widget;
+		EphyEmbed *embed;
+		gboolean handled = FALSE;
+
+		widget = gtk_window_get_focus (GTK_WINDOW (window));
+
+		if (GTK_IS_WIDGET (widget))
+		{
+			handled = gtk_widget_event (widget, (GdkEvent*)event);
+		}
+
+		embed = ephy_window_get_active_embed (window);
+		if (handled == FALSE && embed != NULL)
+		{
+			ephy_embed_activate (embed);
+			ephy_embed_stop_load (embed);
+
+			handled = TRUE;
+		}
+
+		return handled;
+	}
+		
 	/* Don't activate menubar in ppv mode, or in lockdown mode */
 	if (window->priv->ppv_mode || eel_gconf_get_boolean (CONF_LOCKDOWN_HIDE_MENUBAR))
 	{
@@ -1113,17 +1147,11 @@ setup_ui_manager (EphyWindow *window)
 static void
 sync_tab_address (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 {
-	const char *address;
-
 	if (window->priv->closing) return;
 
-	address = ephy_tab_get_location (tab);
-	if (address == NULL)
-	{
-		address = "";
-	}
-
-	ephy_toolbar_set_location (window->priv->toolbar, address);
+	ephy_toolbar_set_location (window->priv->toolbar,
+				   ephy_tab_get_address (tab),
+				   ephy_tab_get_typed_address (tab));
 }
 
 static void
@@ -1430,19 +1458,15 @@ sync_tab_load_status (EphyTab *tab,
 }
 
 static void
-sync_tab_title (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
+sync_tab_title (EphyTab *tab,
+		GParamSpec *pspec,
+		EphyWindow *window)
 {
-	const char *title;
+	EphyWindowPrivate *priv = window->priv;
 
-	if (window->priv->closing) return;
+	if (priv->closing) return;
 
-	title = ephy_tab_get_title (tab);
-
-	if (title)
-	{
-		gtk_window_set_title (GTK_WINDOW(window),
-				      title);
-	}
+	gtk_window_set_title (GTK_WINDOW(window), ephy_tab_get_title (tab));
 }
 
 static void
@@ -1534,11 +1558,13 @@ popup_menu_at_coords (GtkMenu *menu, gint *x, gint *y, gboolean *push_in,
 {
 	GtkWidget *window = GTK_WIDGET (user_data);
 	EphyEmbedEvent *event;
+	guint ux, uy;
 
 	event = g_object_get_data (G_OBJECT (window), "context_event");
 	g_return_if_fail (event != NULL);
 
-	ephy_embed_event_get_coords (event, x, y);
+	ephy_embed_event_get_coords (event, &ux, &uy);
+	*x = ux; *y = uy;
 
 	/* FIXME: better position the popup within the window bounds? */
 	ephy_gui_sanitise_popup_position (menu, window, x, y);
@@ -2041,7 +2067,7 @@ modal_alert_cb (EphyEmbed *embed,
 
 	/* make sure the location entry shows the real URL of the tab's page */
 	address = ephy_embed_get_location (embed, TRUE);
-	ephy_toolbar_set_location (priv->toolbar, address);
+	ephy_toolbar_set_location (priv->toolbar, address, NULL);
 	g_free (address);
 
 	/* don't suppress alert */
@@ -3261,21 +3287,6 @@ ephy_window_notebook_switch_page_cb (GtkNotebook *notebook,
 	update_tabs_menu_sensitivity (window);
 }
 
-/**
- * ephy_window_find:
- * @window: an #EphyWindow
- *
- * Displays @window's Find dialog.
- **/
-void
-ephy_window_find (EphyWindow *window)
-{
-	EphyWindowPrivate *priv = window->priv;
-
-	ephy_find_toolbar_open (priv->find_toolbar, FALSE, FALSE);
-	gtk_widget_grab_focus (GTK_WIDGET (priv->find_toolbar));
-}
-
 /**
  * ephy_window_set_zoom:
  * @window: an #EphyWindow
