@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: pdm-dialog.c,v 1.52 2005/01/28 22:24:46 chpe Exp $
+ *  $Id: pdm-dialog.c,v 1.53 2005/05/01 19:50:36 chpe Exp $
  */
 
 #include "config.h"
@@ -184,7 +184,7 @@ pdm_dialog_show_help (PdmDialog *pd)
 	GtkWidget *notebook, *window;
 	int id;
 
-	char *help_preferences[] = {
+	static char * const help_preferences[] = {
 		"managing-cookies",
 		"managing-passwords"
 	};
