@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.110 2005/05/01 19:48:05 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.111 2005/07/11 20:23:10 chpe Exp $
  */
 
 #include "config.h"
@@ -1192,6 +1192,12 @@ prefs_dialog_init (PrefsDialog *pd)
 
 	pd->priv = EPHY_PREFS_DIALOG_GET_PRIVATE (pd);
 
+#ifdef ENABLE_NLS
+        /* Initialize the control centre domain */
+        bindtextdomain (GTK_DOMAIN, GNOMELOCALEDIR);
+        bind_textdomain_codeset(GTK_DOMAIN, "UTF-8");
+#endif
+
 	ephy_dialog_construct (dialog,
 			       properties,
 			       ephy_file ("prefs-dialog.glade"),
